[ofw] [PATCH] core [5/5]
Reuven Amitai
reuven at mellanox.co.il
Wed Apr 9 06:18:08 PDT 2008
Hi
The following patch adds work completion status : "IB_WCS_REM_ABORT_ERR"
Thanks, Reuven.
Index: core/al/ib_statustext.c
===================================================================
--- core/al/ib_statustext.c (revision 1047)
+++ core/al/ib_statustext.c (working copy)
@@ -168,6 +168,7 @@
"IB_WCS_REM_INVALID_REQ_ERR",
"IB_WCS_BAD_RESP_ERR",
"IB_WCS_LOCAL_ACCESS_ERR",
+ "IB_WCS_REM_ABORT_ERR",
"IB_WCS_GENERAL_ERR",
"IB_WCS_UNMATCHED_RESPONSE", /* InfiniBand Access
Layer */
"IB_WCS_CANCELED", /*
InfiniBand Access Layer */
Index: inc/iba/ib_types.h
===================================================================
--- inc/iba/ib_types.h (revision 1047)
+++ inc/iba/ib_types.h (working copy)
@@ -10417,7 +10417,8 @@
IB_WCS_REM_INVALID_REQ_ERR,
IB_WCS_BAD_RESP_ERR,
IB_WCS_LOCAL_ACCESS_ERR,
- IB_WCS_GENERAL_ERR,
+ IB_WCS_REM_ABORT_ERR,
+ IB_WCS_GENERAL_ERR,
IB_WCS_UNMATCHED_RESPONSE, /* InfiniBand Access
Layer */
IB_WCS_CANCELED, /* InfiniBand Access
Layer */
IB_WCS_UNKNOWN /* Must be last.
*/
@@ -10481,15 +10482,19 @@
* - There was insufficient buffers to receive a new
atomic operation.
* - An RDMA request was larger than 2^31 bytes.
*
* IB_WCS_BAD_RESP_ERR,
* An unexpected transport layer opcode was returned
* by the responder.
*
* IB_WCS_LOCAL_ACCESS_ERR,
* A protection error occurred on a local data buffer
* during the processing of a RDMA Write with Immediate Data
* operation sent from the remote node.
*
an SRQ,
+* the responder aborted the operation).
+*
* IB_WCS_UNMATCHED_RESPONSE
* A response MAD was received for which there was no matching
send. The
* send operation may have been canceled by the user or may
have timed
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.openfabrics.org/pipermail/ofw/attachments/20080409/55d59a54/attachment.html>
-------------- next part --------------
A non-text attachment was scrubbed...
Name: wc_status.patch
Type: application/octet-stream
@@ -10481,15 +10482,19 @@
* - An RDMA request was larger than 2^31 bytes.
*
- * IB_WCS_BAD_RESP_ERR,
- * An unexpected transport layer opcode was returned
- * by the responder.
- *
- * IB_WCS_LOCAL_ACCESS_ERR,
- * A protection error occurred on a local data buffer
- * during the processing of a RDMA Write with Immediate Data
- * operation sent from the remote node.
- *
+* IB_WCS_BAD_RESP_ERR,
+* An unexpected transport layer opcode was returned
+* by the responder.
+*
+* IB_WCS_LOCAL_ACCESS_ERR,
+* A protection error occurred on a local data buffer
+* during the processing of a RDMA Write with Immediate Data
+* operation sent from the remote node.
+*
+* IB_WCS_REM_ABORT_ERR,
+* The operation was aborted (e.g., For UD QPs associated with
an SRQ,
Size: 2085 bytes
Desc: wc_status.patch
URL: <http://lists.openfabrics.org/pipermail/ofw/attachments/20080409/55d59a54/attachment.obj>
More information about the ofw
mailing list